@@ -1,6 +1,6 @@
 # Ebay.pm
 # by Martin Thurn
-# $Id: Ebay.pm,v 2.143 2004/04/22 03:36:05 Daddy Exp $
+# $Id: Ebay.pm,v 2.144 2004/06/06 02:55:44 Daddy Exp $
 
 =head1 NAME
 
@@ -26,7 +26,9 @@ be done through L<WWW::Search> objects.
 
 =head1 NOTES
 
-The search is done against CURRENT running auctions only.
+The search is done against CURRENT running AUCTIONS only.
+(NOT complete auctions, NOT eBay Stores items, NOT Buy-It-Now only items.)
+(If you want to search eBay Stores, use the WWW::Search::Ebay::Stores module.)
 
 The query is applied to TITLES only.
 
@@ -87,7 +89,7 @@ use Data::Dumper;  # for debugging only
 use WWW::Search qw( generic_option strip_tags );
 use WWW::Search::Result;
 
-$VERSION = do { my @r = (q$Revision: 2.143 $ =~ /\d+/g); sprintf "%d."."%03d" x $#r, @r };
+$VERSION = do { my @r = (q$Revision: 2.144 $ =~ /\d+/g); sprintf "%d."."%03d" x $#r, @r };
 $MAINTAINER = 'Martin Thurn <mthurn@cpan.org>';
 
 sub native_setup_search
@@ -163,6 +165,12 @@ sub preprocess_results_page_OFF
   } # preprocess_results_page
 
 
+sub currency_pattern
+  {
+  # A pattern to match all possible currencies found in eBay listings:
+  return qr/(?:\$|C|EUR|GBP)/;
+  } # currency_pattern
+
 # private
 sub parse_tree
   {
@@ -171,8 +179,6 @@ sub parse_tree
 
   # A pattern to match HTML whitespace:
   my $W = q{[\ \t\r\n\240]};
-  # A pattern to match Ebay currencies:
-  my $currency = qr/(?:\$|C|EUR|GBP)/;
   my $hits_found = 0;
   # The hit count is in a FONT tag:
   my @aoFONT = $tree->look_down('_tag' => 'td',
@@ -187,6 +193,7 @@ sub parse_tree
       last FONT;
       } # if
     } # foreach
+  my $currency = $self->currency_pattern;
   # The list of matching items is in a table.  The first column of the
   # table is nothing but icons; the second column is the good stuff.
   my @aoTD = $tree->look_down('_tag', 'td',
